@@ -6,8 +6,8 @@
 #
 # maintained by the
 # @author Chart Group at Geodetic Fundamental Station Wettzell (Chart@fs.wettzell.de)
-# @date 2011-11-25
-# @version 2.4.3
+# @date 2012-01-06
+# @version 2.4.4
 #
 #---------------------------------------------------------------------
 # History:
@@ -20,13 +20,13 @@
 
 package Chart::Composite;
 
-use Chart::Base '2.4.3';
+use Chart::Base '2.4.4';
 use GD;
 use Carp;
 use strict;
 
 @Chart::Composite::ISA     = qw(Chart::Base);
-$Chart::Composite::VERSION = '2.4.3';
+$Chart::Composite::VERSION = '2.4.4';
 
 #>>>>>>>>>>>>>>>>>>>>>>>>>>#
 #  public methods go here  #
@@ -259,6 +259,15 @@ sub _split_data
         $self->{'sub_1'}->set( 'brush_size' => $self->{'opts'}{'brush_size2'} );
     }
 
+    if ( $self->{'opts'}{'brushStyle1'} )
+    {
+        $self->{'sub_0'}->set( 'brushStyle' => $self->{'opts'}{'brushStyle1'} );
+    }
+    if ( $self->{'opts'}{'brushStyle2'} )
+    {
+        $self->{'sub_1'}->set( 'brushStyle' => $self->{'opts'}{'brushStyle2'} );
+    }
+
     #  f_y_tick for left and right axis
     if ( defined( $self->{'opts'}{'f_y_tick1'} ) )
     {
